@@ -6,7 +6,7 @@ Mojolicious::Plugin::PayPal - Make payments using PayPal
 
 =head1 VERSION
 
-0.05
+0.06
 
 =head1 DESCRIPTION
 
@@ -91,7 +91,7 @@ use Mojo::JSON 'j';
 use Mojo::UserAgent;
 use constant DEBUG => $ENV{MOJO_PAYPAL_DEBUG} || 0;
 
-our $VERSION = '0.05';
+our $VERSION = '0.06';
 
 =head1 ATTRIBUTES
 
@@ -403,7 +403,7 @@ sub register {
     paypal => sub {
       my $c = shift;
       return $self unless @_;
-      my $method = shift .'_payment';
+      my $method = sprintf '%s_payment', shift;
       $self->$method($c, @_);
       return $c;
     }
